@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
-# Copyright 2007-2021 The HyperSpy developers
+# Copyright 2007-2022 The HyperSpy developers
 #
-# This file is part of  HyperSpy.
+# This file is part of HyperSpy.
 #
-#  HyperSpy is free software: you can redistribute it and/or modify
+# HyperSpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-#  HyperSpy is distributed in the hope that it will be useful,
+# HyperSpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with  HyperSpy.  If not, see <http://www.gnu.org/licenses/>.
+# along with HyperSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
 
 from collections.abc import Iterable
 import numpy as np
@@ -218,19 +218,23 @@ def _density_of_mixture(weight_percent,
         [elements_db[element]['Physical_properties']['density (g/cm^3)']
             for element in elements])
     sum_densities = np.zeros_like(weight_percent, dtype='float')
-    if mean == 'harmonic':
-        for i, weight in enumerate(weight_percent):
-            sum_densities[i] = weight / densities[i]
-        sum_densities = sum_densities.sum(axis=0)
-        density = np.sum(weight_percent, axis=0) / sum_densities
-        return np.where(sum_densities == 0.0, 0.0, density)
-    elif mean == 'weighted':
-        for i, weight in enumerate(weight_percent):
-            sum_densities[i] = weight * densities[i]
-        sum_densities = sum_densities.sum(axis=0)
-        sum_weight = np.sum(weight_percent, axis=0)
-        density = sum_densities / sum_weight
-        return np.where(sum_weight == 0.0, 0.0, density)
+    try : 
+        if mean == 'harmonic':
+            for i, weight in enumerate(weight_percent):
+                sum_densities[i] = weight / densities[i]
+            sum_densities = sum_densities.sum(axis=0)
+            density = np.sum(weight_percent, axis=0) / sum_densities
+            return np.where(sum_densities == 0.0, 0.0, density)
+        elif mean == 'weighted':
+            for i, weight in enumerate(weight_percent):
+                sum_densities[i] = weight * densities[i]
+            sum_densities = sum_densities.sum(axis=0)
+            sum_weight = np.sum(weight_percent, axis=0)
+            density = sum_densities / sum_weight
+            return np.where(sum_weight == 0.0, 0.0, density)
+    except TypeError : 
+        raise ValueError(
+            'The density of one of the elements is unknown (Probably At or Fr).')
 
 
 def density_of_mixture(weight_percent,
